# nc5ng-python


Python Libary for Datum Transformations on NGS `NADCON5.0` Data

Source of the package `nc5ng` on PyPi ([Link](https://pypi.org/project/nc5ng/))

Install with 

`pip install nc5ng`



## Documentation

[Docs](https://nc5ng.readthedocs.io/)
[Project Page](https://www.nc5ng.org/projects/nc5ng-python)



## Additional Libraries

This package has internal dependencies on [`nadcon5-ng`](https://github.com/nc5ng/nadcon5-ng) and [`nc5ng-python-common`](https://github.com/nc5ng/nc5ng-python-common). This is done for convenience of packaging and they can be though of as one package, however development versions may differ slightly.
